//----------------------------------------------------------------------------
#ifndef AboutBoxfrmH
#define AboutBoxfrmH
//----------------------------------------------------------------------------
#include <vcl\System.hpp>
#include <vcl\Windows.hpp>
#include <vcl\SysUtils.hpp>
#include <vcl\Classes.hpp>
#include <vcl\Graphics.hpp>
#include <vcl\Forms.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Buttons.hpp>
#include <vcl\ExtCtrls.hpp>
#include <vcl\ComCtrls.hpp>

#include "rxricheditx.h"
//----------------------------------------------------------------------------
class TAboutBox : public TForm
{
__published:
	TPanel *Panel1;
	TImage *ProgramIcon;
	TLabel *ProductName;
	TLabel *Version;
	TLabel *Copyright;
	TPanel *Panel2;
	TButton *OKButton;
	TPanel *ModAboutPnl;
	TPanel *CreditAboutPnl;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall ProgramIconMouseDown(TObject *Sender, TMouseButton Button,
          TShiftState Shift, int X, int Y);
	void __fastcall FormCreate(TObject *Sender);
private:
	TRxRichEditX *ModulesAbout;
	TRxRichEditX *CreditAbout;
public:
	void __fastcall RTFURLClick(TObject *Sender, const AnsiString URLText, TMouseButton Button);
	virtual __fastcall TAboutBox(TComponent* AOwner);
};
//----------------------------------------------------------------------------
extern TAboutBox *AboutBox;
//----------------------------------------------------------------------------
#endif    
